==> ocr_image-1.0.0.tar.gz: ocr_image/src/Plugin/Field/FieldWidget/OcrFileWidget.php <==
<?php

namespace Drupal\ocr_image\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Entity\File;
use Drupal\file\Plugin\Field\FieldWidget\FileWidget;
use Drupal\ocr_image\Plugin\Field\TesseractLanguages;
use thiagoalessio\TesseractOCR\TesseractOCR;
use LukeMadhanga\DocumentParser;
use Smalot\PdfParser\Parser;
use PhpOffice\PhpPresentation\IOFactory as PowerpointIOFactory;
use PhpOffice\PhpSpreadsheet\IOFactory;
use PhpOffice\PhpPresentation\Shape\RichText;
use Symfony\Polyfill\Intl\Normalizer\Normalizer;

/**
 * Plugin implementation of the 'Ocr pdf' widget.
 *
 * @FieldWidget(
 *   id = "ocr_pdf",
 *   label = @Translation("Ocr/parser file"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class OcrFileWidget extends FileWidget {

  use Base;

  /**
   * {@inheritDoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    $field_name = $items->getName();
    if (!empty($field_text_name = $this->getSetting('text_field'))) {
      $fid = $form_state->getValue($field_name);
      if (!empty($fid)) {
        if (is_array($fid)) {
          $fid = end($fid);
          if (is_array($fid) && !empty($fid["fids"])) {
            $fid = end($fid["fids"]);
          }
        }
        $file = File::load($fid);
        $uri = $file->getFileUri();
        $stream_wrapper_manager = \Drupal::service('stream_wrapper_manager')
          ->getViaUri($uri);
        $file_path = $stream_wrapper_manager->realpath();
        $language = $this->getSetting('language');
        if (empty($language)) {
          $language = TesseractLanguages::tesseractConvertLang();
        }
        $line_datas = $this->getLinesText($file_path, $language, $this->getSetting('limit'));
        if (!empty($line_datas)) {
          $ocr = implode(PHP_EOL, $line_datas);
          $form_state->setValue($field_text_name, $ocr);
          $element["#default_value"]["description"] = $ocr;
          $element['#attached']['drupalSettings']['ocr_field_widget'] = [
            'field_name' => $field_name,
            'field' => $field_text_name,
            'ocr' => $ocr,
          ];
          $element['#attached']['library'][] = 'ocr_image/ocr_image';
        }
      }
    }

    return $element;
  }

  /**
   * Returns string from image.
   *
   * @param string $file
   *   The directory image.
   * @param string $lang
   *   Language to ocr.
   * @param int $limit
   *   Limited characters.
   * @param int $dpi
   *   Dpi.
   *
   * @return array
   *   The array string line text.
   */
  public function getLinesText($file, $lang = 'eng', $limit = '', $dpi = 300) {
    $mimetype = mime_content_type($file);
    switch ($mimetype) {
      case 'text/html':
      case 'text/plain':
      case 'application/rtf':
      case 'application/msword':
      case 'application/vnd.openxmlformats-officedocument.wordprocessingml.document':
      case 'application/vnd.oasis.opendocument.text':
      case 'word/document.xml':
      case 'content.xml':
      case 'application/octet-stream':
        $data = DocumentParser::parseFromFile($file);
        break;

      case 'application/vnd.openxmlformats-officedocument.spreadsheetml.sheet':
      case 'application/vnd.ms-excel.sheet.macroEnabled.12':
      case 'application/vnd.ms-excel.template.macroEnabled.12':
      case 'application/vnd.ms-excel.sheet.binary.macroEnabled.12':
      case 'application/vnd.ms-excel':
        $reader = IOFactory::createReaderForFile($file);
        $reader->setReadDataOnly(TRUE);
        $spreadsheet = $reader->load($file);
        $sheetData = $spreadsheet->getActiveSheet()
          ->toArray(NULL, TRUE, TRUE, TRUE);
        $data = '';
        foreach ($sheetData as $line) {
          $data .= trim(implode("\t", $line)) . PHP_EOL;
          if (!empty($limit) && strlen($data) > $limit) {
            break;
          }
        }
        break;

      case 'application/vnd.openxmlformats-officedocument.presentationml.presentation':
      case 'application/vnd.ms-powerpoint':
      case 'application/vnd.openxmlformats-officedocument.presentationml.slideshow':
        $reader = PowerpointIOFactory::createReader($this->getPowerpointType($mimetype));
        $powerpoint = $reader->load($file);
        $slides = $powerpoint->getAllSlides();
        $data = '';
        foreach ($slides as $slide_k => $slide_v) {
          $shapes = $slides[$slide_k]->getShapeCollection();
          foreach ($shapes as $shape_k => $shape_v) {
            $shape = $shapes[$shape_k];
            if ($shape instanceof RichText) {
              $paragraphs = $shapes[$shape_k]->getParagraphs();
              foreach ($paragraphs as $paragraph_v) {
                $text_elements = $paragraph_v->getRichTextElements();
                foreach ($text_elements as $text_element_v) {
                  $data .= trim($text_element_v->getText());
                  if (!empty($limit) && strlen($data) > $limit) {
                    break;
                  }
                }
              }
            }
          }
        }
        break;

      case 'image/gif':
      case 'image/jpeg':
      case 'image/bmp':
      case 'image/png':
        $ocr = new TesseractOCR($file);
        $data = '';
        try {
          $data = $ocr->lang($lang)->dpi($dpi)->run();
        }
        catch (\Exception $e) {
          $this->messenger()->addError($this->t("TesseractOCR not found"));
        }
        break;

      case 'application/pdf':
        $parser = new Parser();
        $document = $parser->parseFile($file);
        $data = $document->getText();
        if ($data != "") {
          break;
        }
        else {
          // Check Pdf is image pdf.
          $images = $document->getObjectsByType('XObject', 'Image');
          $data = '';
          foreach ($images as $image) {
            $img_data = $image->getContent();
            $size = getimagesizefromstring(base64_decode($img_data));
            $ocr = (new TesseractOCR())->imageData($img_data, $size);
            $data .= $ocr->lang($lang)->dpi($dpi)->run();
            if (!empty($limit) && strlen($data) > $limit) {
              break;
            }
          }
          break;
        }

    }
    $data = Normalizer::normalize(trim($data), Normalizer::FORM_C);
    $line_datas = array_filter(explode(PHP_EOL, $data), function ($value) {
      return !empty(trim($value));
    });

    return $line_datas;
  }

  /**
   * {@inheritdoc}
   */
  protected function getPowerpointType($type) {
    switch ($type) {
      case 'application/vnd.openxmlformats-officedocument.presentationml.presentation':
        $readerType = 'PowerPoint2007';
        break;

      case 'application/vnd.ms-powerpoint':
        $readerType = 'PowerPoint97';
        break;

      case 'application/vnd.openxmlformats-officedocument.presentationml.slideshow':
        $readerType = 'PowerPoint97';
        break;
    }
    return $readerType;
  }

}

==> ocr_image-1.0.1.tar.gz: ocr_image/src/Plugin/Field/FieldWidget/OcrFileWidget.php <==
<?php

namespace Drupal\ocr_image\Plugin\Field\FieldWidget;

use Drupal\Core\Field\FieldItemListInterface;
use Drupal\Core\Form\FormStateInterface;
use Drupal\file\Entity\File;
use Drupal\file\Plugin\Field\FieldWidget\FileWidget;
use Drupal\ocr_image\Plugin\Field\TesseractLanguages;

/**
 * Plugin implementation of the 'Ocr pdf' widget.
 *
 * @FieldWidget(
 *   id = "ocr_pdf",
 *   label = @Translation("Ocr/parser file"),
 *   field_types = {
 *     "file"
 *   }
 * )
 */
class OcrFileWidget extends FileWidget {

  use Base;

  /**
   * {@inheritDoc}
   */
  public function formElement(FieldItemListInterface $items, $delta, array $element, array &$form, FormStateInterface $form_state) {
    $element = parent::formElement($items, $delta, $element, $form, $form_state);
    $field_name = $items->getName();
    if (!empty($field_text_name = $this->getSetting('text_field'))) {
      $fid = $form_state->getValue($field_name);
      if (!empty($fid)) {
        if (is_array($fid)) {
          $fid = end($fid);
          if (is_array($fid) && !empty($fid["fids"])) {
            $fid = end($fid["fids"]);
          }
        }
        $file = File::load($fid);
        $uri = $file->getFileUri();
        $stream_wrapper_manager = \Drupal::service('stream_wrapper_manager')
          ->getViaUri($uri);
        $file_path = $stream_wrapper_manager->realpath();
        $language = $this->getSetting('language');
        if (empty($language)) {
          $language = TesseractLanguages::tesseractConvertLang();
        }
        $doc_parser_service = \Drupal::service('ocr_image.DocParser');
        $line_datas = $doc_parser_service->getText($file_path, $language, $this->getSetting('limit'));
        if (!empty($line_datas)) {
          $ocr = implode(" " . PHP_EOL, $line_datas);
          $form_state->setValue($field_text_name, $ocr);
          $element["#default_value"]["description"] = strip_tags($ocr);
          $element['#attached']['drupalSettings']['ocr_field_widget'] = [
            'field_name' => $field_name,
            'field' => $field_text_name,
            'ocr' => $ocr,
          ];
          $element['#attached']['library'][] = 'ocr_image/ocr_image';
        }
      }
    }

    return $element;
  }

}
